==> haskell-basement-0.0.11-10-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-basement.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 basement
version:              0.0.11
visibility:           public
id:                   basement-0.0.11-CejmV4k3OtGGKPkDYOlSof
key:                  basement-0.0.11-CejmV4k3OtGGKPkDYOlSof
license:              BSD-3-Clause
copyright:
    2015-2017 Vincent Hanquez <vincent@snarc.org>
    , 2017-2018 Foundation Maintainers

maintainer:           vincent@snarc.org
homepage:             https://github.com/haskell-foundation/foundation#readme
synopsis:             Foundation scrap box of array & string
description:          Foundation most basic primitives without any dependencies
category:             Web
abi:                  02a22e9ba7835b8d54f66a6d299c78a7
exposed:              True
exposed-modules:
    Basement.Alg.XorShift Basement.Base16 Basement.Bindings.Memory
    Basement.Bits Basement.Block Basement.Block.Builder
    Basement.Block.Mutable Basement.BlockN Basement.Bounded
    Basement.BoxedArray Basement.Cast Basement.Compat.AMP
    Basement.Compat.Base Basement.Compat.Bifunctor
    Basement.Compat.C.Types Basement.Compat.CallStack
    Basement.Compat.ExtList Basement.Compat.Identity
    Basement.Compat.IsList Basement.Compat.MonadTrans
    Basement.Compat.Natural Basement.Compat.NumLiteral
    Basement.Compat.PrimTypes Basement.Compat.Primitive
    Basement.Compat.Semigroup Basement.Compat.Typeable
    Basement.Endianness Basement.Environment Basement.Exception
    Basement.FinalPtr Basement.Floating Basement.From Basement.Imports
    Basement.IntegralConv Basement.Monad Basement.MutableBuilder
    Basement.Nat Basement.NonEmpty Basement.NormalForm
    Basement.Numerical.Additive Basement.Numerical.Multiplicative
    Basement.Numerical.Number Basement.Numerical.Subtractive
    Basement.PrimType Basement.Sized.Block Basement.Sized.List
    Basement.Sized.UVect Basement.Sized.Vect Basement.String
    Basement.String.Builder Basement.Terminal Basement.Terminal.ANSI
    Basement.These Basement.Types.AsciiString Basement.Types.Char7
    Basement.Types.CharUTF8 Basement.Types.OffsetSize
    Basement.Types.Ptr Basement.Types.Word128 Basement.Types.Word256
    Basement.UArray Basement.UArray.Mutable

hidden-modules:
    Basement.Error Basement.Show Basement.Runtime Basement.Alg.Class
    Basement.Alg.Mutable Basement.Alg.PrimArray Basement.Alg.UTF8
    Basement.Alg.String Basement.Numerical.Conversion
    Basement.Block.Base Basement.UTF8.Base Basement.UTF8.Helper
    Basement.UTF8.Table Basement.UTF8.Types Basement.UArray.Base
    Basement.String.CaseMapping Basement.String.Encoding.Encoding
    Basement.String.Encoding.UTF16 Basement.String.Encoding.UTF32
    Basement.String.Encoding.ASCII7 Basement.String.Encoding.ISO_8859_1
    Basement.Terminal.Size

import-dirs:          /usr/lib/ghc-8.10.4/site-local/basement-0.0.11
library-dirs:         /usr/lib/ghc-8.10.4/site-local/basement-0.0.11
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/basement-0.0.11
hs-libraries:         HSbasement-0.0.11-CejmV4k3OtGGKPkDYOlSof
depends:              base-4.14.1.0 ghc-prim-0.6.1
haddock-interfaces:   /usr/share/doc/haskell-basement/html/basement.haddock
haddock-html:         /usr/share/doc/haskell-basement/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-basement-0.0.12-1-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-basement.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 basement
version:              0.0.12
visibility:           public
id:                   basement-0.0.12-5npdMLTFbggC6Tq5xCCXFT
key:                  basement-0.0.12-5npdMLTFbggC6Tq5xCCXFT
license:              BSD-3-Clause
copyright:
    2015-2017 Vincent Hanquez <vincent@snarc.org>
    , 2017-2018 Foundation Maintainers

maintainer:           vincent@snarc.org
homepage:             https://github.com/haskell-foundation/foundation#readme
synopsis:             Foundation scrap box of array & string
description:          Foundation most basic primitives without any dependencies
category:             Web
abi:                  997af77a799722ebe95bdb4a88bfa151
exposed:              True
exposed-modules:
    Basement.Alg.XorShift Basement.Base16 Basement.Bindings.Memory
    Basement.Bits Basement.Block Basement.Block.Builder
    Basement.Block.Mutable Basement.BlockN Basement.Bounded
    Basement.BoxedArray Basement.Cast Basement.Compat.AMP
    Basement.Compat.Base Basement.Compat.Bifunctor
    Basement.Compat.C.Types Basement.Compat.CallStack
    Basement.Compat.ExtList Basement.Compat.Identity
    Basement.Compat.IsList Basement.Compat.MonadTrans
    Basement.Compat.Natural Basement.Compat.NumLiteral
    Basement.Compat.PrimTypes Basement.Compat.Primitive
    Basement.Compat.Semigroup Basement.Compat.Typeable
    Basement.Endianness Basement.Environment Basement.Exception
    Basement.FinalPtr Basement.Floating Basement.From Basement.Imports
    Basement.IntegralConv Basement.Monad Basement.MutableBuilder
    Basement.Nat Basement.NonEmpty Basement.NormalForm
    Basement.Numerical.Additive Basement.Numerical.Multiplicative
    Basement.Numerical.Number Basement.Numerical.Subtractive
    Basement.PrimType Basement.Sized.Block Basement.Sized.List
    Basement.Sized.UVect Basement.Sized.Vect Basement.String
    Basement.String.Builder Basement.Terminal Basement.Terminal.ANSI
    Basement.These Basement.Types.AsciiString Basement.Types.Char7
    Basement.Types.CharUTF8 Basement.Types.OffsetSize
    Basement.Types.Ptr Basement.Types.Word128 Basement.Types.Word256
    Basement.UArray Basement.UArray.Mutable

hidden-modules:
    Basement.Error Basement.Show Basement.Runtime Basement.Alg.Class
    Basement.Alg.Mutable Basement.Alg.PrimArray Basement.Alg.UTF8
    Basement.Alg.String Basement.Numerical.Conversion
    Basement.Block.Base Basement.UTF8.Base Basement.UTF8.Helper
    Basement.UTF8.Table Basement.UTF8.Types Basement.UArray.Base
    Basement.String.CaseMapping Basement.String.Encoding.Encoding
    Basement.String.Encoding.UTF16 Basement.String.Encoding.UTF32
    Basement.String.Encoding.ASCII7 Basement.String.Encoding.ISO_8859_1
    Basement.Terminal.Size

import-dirs:          /usr/lib/ghc-8.10.4/site-local/basement-0.0.12
library-dirs:         /usr/lib/ghc-8.10.4/site-local/basement-0.0.12
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/basement-0.0.12
hs-libraries:         HSbasement-0.0.12-5npdMLTFbggC6Tq5xCCXFT
depends:              base-4.14.1.0 ghc-prim-0.6.1
haddock-interfaces:   /usr/share/doc/haskell-basement/html/basement.haddock
haddock-html:         /usr/share/doc/haskell-basement/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
